@@ -4,17 +4,16 @@ import re
 
 from typing import Match
 
+__all__ = ('rm_js_comments', 'strip_comments', 'STRIP_JSON_COMMENTS_REGEX')
 
-__all__ = ["rm_js_comments", "strip_comments"]
-
-STRIP_JSON_COMMENTS_REGEX = r"(\".*?(?<!\\)\"|\'.*?(?<!\\)\')|(/\*.*?\*/|//[^\r\n]*$)"
+STRIP_JSON_COMMENTS_REGEX = r'(\".*?(?<!\\)\"|\'.*?(?<!\\)\')|(/\*.*?\*/|//[^\r\n]*$)'
 
 
-def _strip_json_comments_regex_replacer(match: Match[str]) -> str:  # type: ignore
+def _strip_json_comments_regex_replacer(match: Match[str]) -> str:
     # if the 2nd group (capturing comments) is not None,
     # it means we have captured a non-quoted (real) comment string.
     if match.group(2) is not None:
-        return ""  # so we will return empty to remove the comment
+        return ''  # so we will return empty to remove the comment
     return match.group(1)  # captured quoted-string
 
 
